@@ -628,3 +628,158 @@ Ext.override(Ext.Element, {
         return ttlSize;
     }
 });
+
+/**
+ * BOBUH-19922 Добавлен вызов ивента beforeaddmenuitem перед добавлением элементов в контекстное меню колонки
+ * Было:
+ *     menu.add(new Ext.menu.CheckItem({
+ *                         itemId: "col-" + cm.getColumnId(col),
+ *                         text: text.join(' '),
+ *                         checked: !cm.isHidden(col),
+ *                         hideOnClick: false,
+ *                         disabled: cm.config[col].hideable === false
+ *                     }));
+ * Стало:
+ *     var newMenuItem = new Ext.menu.CheckItem({
+ *                         itemId: "col-" + cm.getColumnId(col),
+ *                         text: text.join(' '),
+ *                         checked: !cm.isHidden(col),
+ *                         hideOnClick: false,
+ *                         disabled: cm.config[col].hideable === false
+ *                     });
+ *                     cm.fireEvent('beforeaddmenuitem', cm, newMenuItem);
+ *                     menu.add(newMenuItem);
+ */
+function beforeColMenuShow(){
+    var cm = this.cm,
+        rows = this.cm.rows,
+        menu,
+        text,
+        group,
+        gcol,
+        r,
+        title;
+    this.colMenu.removeAll();
+
+    for(var col = 0, clen = cm.getColumnCount(); col < clen; col++){
+        menu = this.colMenu;
+        title = cm.getColumnHeader(col);
+        text = [];
+
+        if(cm.config[col].fixed !== true && cm.config[col].hideable !== false){
+
+            for(var row = 0, rlen = rows.length; row < rlen; row++){
+                r = rows[row];
+                gcol = 0;
+
+                for(var i = 0, len = r.length; i < len; i++){
+                    group = r[i];
+
+                    if(col >= gcol && col < gcol + group.colspan){
+                        break;
+                    }
+                    gcol += group.colspan;
+                }
+
+                if(group && group.header){
+
+                    if(cm.hierarchicalColMenu){
+                        var gid = 'group-' + row + '-' + gcol,
+                            item = menu.items ? menu.getComponent(gid) : null,
+                            submenu = item ? item.menu : null;
+
+                        if(!submenu){
+                            submenu = new Ext.menu.Menu({
+                                itemId: gid
+                            });
+                            submenu.on("itemclick", this.handleHdMenuClick, this);
+                            var checked = false,
+                                disabled = true;
+
+                            for(var c = gcol, lc = gcol + group.colspan; c < lc; c++){
+
+                                if(!cm.isHidden(c)){
+                                    checked = true;
+                                }
+
+                                if(cm.config[c].hideable !== false){
+                                    disabled = false;
+                                }
+                            }
+                            menu.add({
+                                itemId: gid,
+                                text: group.header,
+                                menu: submenu,
+                                hideOnClick: false,
+                                checked: checked,
+                                disabled: disabled
+                            });
+                        }
+                        menu = submenu;
+                    }
+
+                    else{
+                        text.push(group.header);
+                    }
+                }
+            }
+            text.push(title);
+            var newMenuItem = new Ext.menu.CheckItem({
+                itemId: "col-" + cm.getColumnId(col),
+                text: text.join(' '),
+                checked: !cm.isHidden(col),
+                hideOnClick: false,
+                disabled: cm.config[col].hideable === false
+            });
+            cm.fireEvent('beforeaddmenuitem', cm, newMenuItem);
+            menu.add(newMenuItem);
+        }
+    }
+};
+
+Ext.override(Ext.ux.grid.ColumnHeaderGroup, {
+    init: function(grid){
+        this.viewConfig.beforeColMenuShow = beforeColMenuShow;
+        Ext.applyIf(grid.colModel, this.config);
+        Ext.apply(grid.getView(),this.viewConfig);
+    }
+});
+
+
+/**
+ * Очень пытливые умы успевают за короткое время несколько раз кликнуть на кнопку. Не спасает даже disabled, потому что
+ * он не успеват сработать. Это в определенных случаях приводит к неприятным последствиям. Например, один документ
+ * может сохраниться дважды и в этом случае мы получаем копии, которые нам не нужны.
+ * Поэтому делаем финт ушами и запоминаем момент последнего клика на кнопке и в течение ближайших 500 миллисекунд не
+ * дадим повторно выполнить это же действие.
+ */
+Ext.override(Ext.Button, {
+    onClick: function(e) {
+        var me = this,
+            now = Date.now();
+
+        if (now < me.lastClickTimestamp + 500) {
+            me.lastClickTimestamp = now;
+            return;
+        }
+        me.lastClickTimestamp = now;
+
+        if (e) {
+            e.preventDefault();
+        }
+        if (e.button !== 0) {
+            return;
+        }
+        if (!this.disabled) {
+            this.doToggle();
+            if (this.menu && !this.hasVisibleMenu() && !this.ignoreNextClick) {
+                this.showMenu();
+            }
+            this.fireEvent('click', this, e);
+            if (this.handler) {
+
+                this.handler.call(this.scope || this, this, e);
+            }
+        }
+    }
+});
\ No newline at end of file
